@@ -9,7 +9,7 @@ use List::Util 1.45 qw( uniq );
 
 BEGIN {
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.018000';
+	our $VERSION   = '0.018001';
 	
 	if ( eval { require Types::Standard; 1 } ) {
 		Types::Standard->import(
@@ -471,7 +471,7 @@ sub get_build_methods {
 sub get_demolish_methods {
 	my $klass = ref($_[0]) || $_[0];
 	__PACKAGE__->populate_demolish( $klass );
-	return @{ $DEMOLISH_CACHE{$klass} };
+	return @{ $DEMOLISH_CACHE{$klass} or [] };
 }
 
 1;
